pub struct WgpuConfig {
pub backends: Backends,
pub power_preference: PowerPreference,
pub force_fallback_adapter: bool,
pub device_label: Option<String>,
pub required_features: Features,
pub required_limits: Limits,
pub memory_hints: MemoryHints,
}Expand description
WGPU configuration for adapter/device creation.
This is intentionally a small, stable subset of WGPU knobs that tend to matter for apps (adapter selection and required features/limits).
Fields
backends: BackendsWhich backends to enable for the WGPU instance.
power_preference: PowerPreferenceAdapter power preference.
force_fallback_adapter: boolWhether to allow selecting a fallback (software) adapter.
device_label: Option<String>Optional device debug label.
required_features: FeaturesFeatures required from the device.
required_limits: LimitsLimits required from the device.
memory_hints: MemoryHintsMemory allocation hints for the device.
Implementations
Sourceimpl WgpuConfig
impl WgpuConfig
Sourcepub fn from_preset(preset: WgpuPreset) -> Self
pub fn from_preset(preset: WgpuPreset) -> Self
Build a WgpuConfig from a curated preset.