#[non_exhaustive]pub enum RunError {
Show 23 variants
EventLoop(EventLoopError),
WindowCreation(OsError),
SurfaceCreation(CreateSurfaceError),
AdapterUnavailable(RequestAdapterError),
SurfaceFormatUnavailable,
SurfaceFormatChanged {
previous: TextureFormat,
replacement: TextureFormat,
},
DeviceRequest(RequestDeviceError),
ImGuiContext(ImGuiError),
ImGuiFrame(RendererConsumerError),
ImGuiFrameOwnership {
stage: ApplicationStage,
before: FrameLifecycleStamp,
after: FrameLifecycleStamp,
},
RendererInit(RendererError),
Render(RendererError),
GpuInvalidation(RendererError),
RendererRelease(RendererError),
Dockspace(DockspaceError),
Platform {
operation: &'static str,
source: WinitPlatformError,
},
MultiViewportUnsupported,
SurfaceValidation,
GpuOutOfMemory {
message: String,
},
GpuValidation {
message: String,
},
GpuInternal {
message: String,
},
Application {
stage: ApplicationStage,
source: Box<dyn StdError + 'static>,
},
Recovery {
message: String,
},
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EventLoop(EventLoopError)
WindowCreation(OsError)
SurfaceCreation(CreateSurfaceError)
SurfaceFormatChanged
DeviceRequest(RequestDeviceError)
ImGuiContext(ImGuiError)
ImGuiFrame(RendererConsumerError)
ImGuiFrameOwnership
RendererInit(RendererError)
Render(RendererError)
GpuInvalidation(RendererError)
RendererRelease(RendererError)
Dockspace(DockspaceError)
Platform
MultiViewportUnsupported
SurfaceValidation
GpuOutOfMemory
GpuValidation
GpuInternal
Application
Recovery
Implementations
Sourceimpl RunError
impl RunError
Sourcepub fn application<E>(stage: ApplicationStage, source: E) -> Selfwhere
E: StdError + 'static,
pub fn application<E>(stage: ApplicationStage, source: E) -> Selfwhere
E: StdError + 'static,
Wraps an application-owned error with the lifecycle stage that produced it.
Sourcepub const fn application_stage(&self) -> Option<ApplicationStage>
pub const fn application_stage(&self) -> Option<ApplicationStage>
Returns the lifecycle stage for an application callback failure.